@@ -70,15 +70,15 @@ wxIMPLEMENT_ABSTRACT_CLASS(wxHtmlParser,wxObject);
 
 wxHtmlParser::wxHtmlParser()
     : wxObject(),
-      m_FS(NULL)
+      m_FS(nullptr)
 {
-    m_Source = NULL;
+    m_Source = nullptr;
     m_entitiesParser = new wxHtmlEntitiesParser;
-    m_Tags = NULL;
-    m_CurTag = NULL;
-    m_TextPieces = NULL;
+    m_Tags = nullptr;
+    m_CurTag = nullptr;
+    m_TextPieces = nullptr;
     m_CurTextPiece = 0;
-    m_SavedStates = NULL;
+    m_SavedStates = nullptr;
 }
 
 wxHtmlParser::~wxHtmlParser()
@@ -86,8 +86,6 @@ wxHtmlParser::~wxHtmlParser()
     while (RestoreState()) {}
     DestroyDOMTree();
 
-    WX_CLEAR_ARRAY(m_HandlersStack);
-    WX_CLEAR_HASH_SET(wxHtmlTagHandlersSet, m_HandlersSet);
     delete m_entitiesParser;
     delete m_Source;
 }
@@ -125,7 +123,7 @@ void wxHtmlParser::SetSource(const wxString& src)
     delete m_Source;
     m_Source = new wxString(src);
     CreateDOMTree();
-    m_CurTag = NULL;
+    m_CurTag = nullptr;
     m_CurTextPiece = 0;
 }
 
@@ -133,7 +131,7 @@ void wxHtmlParser::CreateDOMTree()
 {
     wxHtmlTagsCache cache(*m_Source);
     m_TextPieces = new wxHtmlTextPieces;
-    CreateDOMSubTree(NULL, m_Source->begin(), m_Source->end(), &cache);
+    CreateDOMSubTree(nullptr, m_Source->begin(), m_Source->end(), &cache);
     m_CurTextPiece = 0;
 }
 
@@ -154,7 +152,7 @@ void wxHtmlParser::CreateDOMSubTree(wxHtmlTag *cur,
     // and ending tag verbosely. Setting i=end_pos will skip to the very
     // end of this function where text piece is added, bypassing any child
     // tags parsing (CDATA element can't have child elements by definition):
-    if (cur != NULL && wxIsCDATAElement(cur->GetName()))
+    if (cur != nullptr && wxIsCDATAElement(cur->GetName()))
     {
         i = end_pos;
     }
@@ -185,7 +183,7 @@ void wxHtmlParser::CreateDOMSubTree(wxHtmlTag *cur,
                                         i, end_pos, cache, m_entitiesParser);
                 else
                 {
-                    chd = new wxHtmlTag(NULL, m_Source,
+                    chd = new wxHtmlTag(nullptr, m_Source,
                                         i, end_pos, cache, m_entitiesParser);
                     if (!m_Tags)
                     {
@@ -240,7 +238,7 @@ void wxHtmlParser::DestroyDOMTree()
         delete t1;
         t1 = t2;
     }
-    m_Tags = m_CurTag = NULL;
+    m_Tags = m_CurTag = nullptr;
 
     wxDELETE(m_TextPieces);
 }
@@ -331,7 +329,7 @@ void wxHtmlParser::AddTagHandler(wxHtmlTagHandler *handler)
     while (tokenizer.HasMoreTokens())
         m_HandlersHash[tokenizer.GetNextToken()] = handler;
 
-    m_HandlersSet.insert(handler);
+    m_HandlersSet.insert(std::unique_ptr<wxHtmlTagHandler>(handler));
 
     handler->SetParser(this);
 }
@@ -341,7 +339,9 @@ void wxHtmlParser::PushTagHandler(wxHtmlTagHandler *handler, const wxString& tag
     wxStringTokenizer tokenizer(tags, wxT(", "));
     wxString key;
 
-    m_HandlersStack.push_back(new wxHtmlTagHandlersHash(m_HandlersHash));
+    m_HandlersStack.push(std::unique_ptr<wxHtmlTagHandlersHash>(
+        new wxHtmlTagHandlersHash(m_HandlersHash))
+    );
 
     while (tokenizer.HasMoreTokens())
     {
@@ -355,10 +355,8 @@ void wxHtmlParser::PopTagHandler()
     wxCHECK_RET( !m_HandlersStack.empty(),
                  "attempt to remove HTML tag handler from empty stack" );
 
-    wxHtmlTagHandlersHash *prev = m_HandlersStack.back();
-    m_HandlersStack.pop_back();
-    m_HandlersHash = *prev;
-    delete prev;
+    m_HandlersHash = *m_HandlersStack.top();
+    m_HandlersStack.pop();
 }
 
 void wxHtmlParser::SetSourceAndSaveState(const wxString& src)
@@ -374,11 +372,11 @@ void wxHtmlParser::SetSourceAndSaveState(const wxString& src)
     s->m_nextState = m_SavedStates;
     m_SavedStates = s;
 
-    m_CurTag = NULL;
-    m_Tags = NULL;
-    m_TextPieces = NULL;
+    m_CurTag = nullptr;
+    m_Tags = nullptr;
+    m_TextPieces = nullptr;
     m_CurTextPiece = 0;
-    m_Source = NULL;
+    m_Source = nullptr;
 
     SetSource(src);
 }
@@ -431,35 +429,13 @@ void wxHtmlTagHandler::ParseInnerSource(const wxString& source)
 wxIMPLEMENT_DYNAMIC_CLASS(wxHtmlEntitiesParser, wxObject);
 
 wxHtmlEntitiesParser::wxHtmlEntitiesParser()
-#if !wxUSE_UNICODE
-    : m_conv(NULL), m_encoding(wxFONTENCODING_SYSTEM)
-#endif
 {
 }
 
 wxHtmlEntitiesParser::~wxHtmlEntitiesParser()
 {
-#if !wxUSE_UNICODE
-    delete m_conv;
-#endif
 }
 
-#if !wxUSE_UNICODE
-void wxHtmlEntitiesParser::SetEncoding(wxFontEncoding encoding)
-{
-    if (encoding == m_encoding)
-        return;
-
-    delete m_conv;
-
-    m_encoding = encoding;
-    if (m_encoding == wxFONTENCODING_SYSTEM)
-        m_conv = NULL;
-    else
-        m_conv = new wxCSConv(wxFontMapper::GetEncodingName(m_encoding));
-}
-#endif // !wxUSE_UNICODE
-
 wxString wxHtmlEntitiesParser::Parse(const wxString& input) const
 {
     wxString output;
@@ -486,7 +462,7 @@ wxString wxHtmlEntitiesParser::Parse(const wxString& input) const
 
             for ( ; c != end; ++c )
             {
-                wxChar ch = *c;
+                wxUniChar ch = *c;
                 if ( !((ch >= wxT('a') && ch <= wxT('z')) ||
                        (ch >= wxT('A') && ch <= wxT('Z')) ||
                        (ch >= wxT('0') && ch <= wxT('9')) ||
@@ -516,20 +492,6 @@ wxString wxHtmlEntitiesParser::Parse(const wxString& input) const
     return output;
 }
 
-#if !wxUSE_UNICODE
-wxChar wxHtmlEntitiesParser::GetCharForCode(unsigned code) const
-{
-    char buf[2];
-    wchar_t wbuf[2];
-    wbuf[0] = (wchar_t)code;
-    wbuf[1] = 0;
-    wxMBConv *conv = m_conv ? m_conv : &wxConvLocal;
-    if (conv->WC2MB(buf, wbuf, 2) == (size_t)-1)
-        return '?';
-    return buf[0];
-}
-#endif
-
 struct wxHtmlEntityInfo
 {
     const wxStringCharType *name;
@@ -833,7 +795,7 @@ wxChar wxHtmlEntitiesParser::GetEntityChar(const wxString& entity) const
             ENTITY("zeta", 950),
             ENTITY("zwj", 8205),
             ENTITY("zwnj", 8204),
-            {NULL, 0}};
+            {nullptr, 0}};
         #undef ENTITY
         static size_t substitutions_cnt = 0;
 
@@ -863,7 +825,7 @@ wxFSFile *wxHtmlParser::OpenURL(wxHtmlURLType type,
     if (type == wxHTML_URL_IMAGE)
         flags |= wxFS_SEEKABLE;
 
-    return m_FS ? m_FS->OpenFile(url, flags) : NULL;
+    return m_FS ? m_FS->OpenFile(url, flags) : nullptr;
 
 }
 
@@ -877,10 +839,10 @@ class wxMetaTagParser : public wxHtmlParser
 public:
     wxMetaTagParser() { }
 
-    wxObject* GetProduct() wxOVERRIDE { return NULL; }
+    wxObject* GetProduct() override { return nullptr; }
 
 protected:
-    virtual void AddText(const wxString& WXUNUSED(txt)) wxOVERRIDE {}
+    virtual void AddText(const wxString& WXUNUSED(txt)) override {}
 
     wxDECLARE_NO_COPY_CLASS(wxMetaTagParser);
 };
@@ -889,8 +851,8 @@ class wxMetaTagHandler : public wxHtmlTagHandler
 {
 public:
     wxMetaTagHandler(wxString *retval) : wxHtmlTagHandler(), m_retval(retval) {}
-    wxString GetSupportedTags() wxOVERRIDE { return wxT("META,BODY"); }
-    bool HandleTag(const wxHtmlTag& tag) wxOVERRIDE;
+    wxString GetSupportedTags() override { return wxT("META,BODY"); }
+    bool HandleTag(const wxHtmlTag& tag) override;
 
 private:
     wxString *m_retval;
@@ -906,14 +868,6 @@ bool wxMetaTagHandler::HandleTag(const wxHtmlTag& tag)
         return false;
     }
 
-    // HTML 5 charset
-    if (tag.GetParamAsString(wxT("charset"), m_retval))
-    {
-        m_Parser->StopParsing();
-        return false;
-    }
-
-    // HTML 4 charset
     wxString httpEquiv,
              content;
     if (tag.GetParamAsString(wxT("HTTP-EQUIV"), &httpEquiv) &&
@@ -973,7 +927,7 @@ wxHtmlParser::SkipCommentTag(wxString::const_iterator& start,
     int dashes = 0;
     while ( ++p < end )
     {
-        const wxChar c = *p;
+        const wxUniChar c = *p;
 
         if ( (c == wxT(' ') || c == wxT('\n') ||
               c == wxT('\r') || c == wxT('\t')) && dashes >= 2 )
